#[repr(C)]pub struct PackedNewAddressParams {
pub seed: [u8; 32],
pub address_queue_account_index: u8,
pub address_merkle_tree_account_index: u8,
pub address_merkle_tree_root_index: u16,
}Expand description
Struct passed into the light system program cpi to create a new address.
Fields
seed: [u8; 32]address_queue_account_index: u8address_merkle_tree_account_index: u8address_merkle_tree_root_index: u16Trait Implementations
Sourceimpl BorshDeserialize for NewAddressParamsPacked
impl BorshDeserialize for NewAddressParamsPacked
fn deserialize_reader<__R>(
reader: &mut __R,
) -> Result<NewAddressParamsPacked, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for NewAddressParamsPacked
impl Clone for NewAddressParamsPacked
Sourcefn clone(&self) -> NewAddressParamsPacked
fn clone(&self) -> NewAddressParamsPacked
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NewAddressParamsPacked
Sourceimpl Debug for NewAddressParamsPacked
impl Debug for NewAddressParamsPacked
Sourceimpl Default for NewAddressParamsPacked
impl Default for NewAddressParamsPacked
Sourcefn default() -> NewAddressParamsPacked
fn default() -> NewAddressParamsPacked
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for NewAddressParamsPacked
impl PartialEq for NewAddressParamsPacked
Sourcefn eq(&self, other: &NewAddressParamsPacked) -> bool
fn eq(&self, other: &NewAddressParamsPacked) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NewAddressParamsPacked