pub struct AddressTreeInfo {
pub tree: Pubkey,
pub queue: Pubkey,
}Fields
tree: Pubkeyqueue: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for AddressTreeInfo
impl BorshDeserialize for AddressTreeInfo
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AddressTreeInfo
impl BorshSerialize for AddressTreeInfo
Sourceimpl Clone for AddressTreeInfo
impl Clone for AddressTreeInfo
Sourcefn clone(&self) -> AddressTreeInfo
fn clone(&self) -> AddressTreeInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AddressTreeInfo
Sourceimpl Debug for AddressTreeInfo
impl Debug for AddressTreeInfo
Sourceimpl Default for AddressTreeInfo
impl Default for AddressTreeInfo
Sourcefn default() -> AddressTreeInfo
fn default() -> AddressTreeInfo
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AddressTreeInfo
impl PartialEq for AddressTreeInfo
Sourcefn eq(&self, other: &AddressTreeInfo) -> bool
fn eq(&self, other: &AddressTreeInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AddressTreeInfo